@@ -507,7 +507,7 @@ impl Line {
 impl Bounds for Line {
     fn bounds(&self) -> (Point, Point) {
         let aabb = Segment::new(*self.start, *self.end).local_aabb();
-        (Point::from(*aabb.mins()), Point::from(*aabb.maxs()))
+        (Point::from(*aabb.mins), Point::from(*aabb.maxs))
     }
 }
 
